The plot for changepoints detected by the changepoint package is a line plot for the raw data and the vertical lines representing each changepoint. The x-axis is the row number of the raw data in the original data vector. The plot inherits ggplot2, meaning users can add ggplot2 functions on top the changepoint plot for customization.
Usage
ggcptplot(
data,
change_in = "mean_var",
cp_method = "PELT",
...,
cptline_alpha = 1,
cptline_color = "blue",
cptline_type = "solid",
cptline_linewidth = 0.5,
cptline_size = lifecycle::deprecated(),
index = NULL,
show_points = NULL,
show_line = TRUE
)Arguments
- data
A numeric vector.
- change_in
Choice of
mean_var,mean,var, andnp(orcpt_npfor backward compatibility). Each choice corresponds tocpt.meanvar(),cpt.mean(),cpt.var()andcpt.np()respectively. The default ismean_var.- cp_method
A wide range of choices (i.e.,
AMOC,PELT,SegNeighorBinSeg). Please note whenchange_inisnporcpt_np,PELTis the only option.- ...
Extra arguments for each
cptfunction mentioned in thechange_insection.- cptline_alpha
The value of alpha for the vertical changepoint line(s), default is 1, meaning no transparency.
- cptline_color
The color for the vertical changepoint line(s), default is
blue.- cptline_type
The linetype for the vertical changepoint line(s), default is
solid.- cptline_linewidth
The linewidth for the vertical changepoint line(s), default is
0.5.- cptline_size
Deprecated. Use
cptline_linewidthinstead.- index
Optional. A vector of x-axis labels (e.g. dates) of the same length as
data.- show_points
Logical. Whether to draw data points. Defaults to
TRUEwhenlength(data) <= 500,FALSEotherwise.- show_line
Logical. Whether to draw the line. Defaults to
TRUE.