Renders the changepoints of a result as a gt table, with the time index, location intervals and segment levels formatted for a paper. Falls back to a plain tibble, with a note, when gt is not installed.
Examples
set.seed(2026)
cpt_gt(cpt_detect(c(rnorm(60), rnorm(60, 4)), method = "pelt"))
Changepoints (pelt)
1 changepoint(s) in mean over 120 observations; penalty MBIC
#
Location
Value at change
Level before
Level after
Change