Wraps the fpop package for optimal changepoint detection via
functional pruning.
Arguments
- x
A numeric vector.
- penalty
Penalty value. Defaults to
2 * log(length(x))(BIC).- ...
Additional arguments passed to
fpop::Fpop().
Wraps the fpop package for optimal changepoint detection via
functional pruning.
A numeric vector.
Penalty value. Defaults to 2 * log(length(x)) (BIC).
Additional arguments passed to fpop::Fpop().