Returns a tidy tibble combining the results of multiple detectors on the same series.
Usage
ggcpt_compare_table(
x,
methods = c("pelt", "binseg", "amoc"),
change_in = "mean",
...
)Returns a tidy tibble combining the results of multiple detectors on the same series.
ggcpt_compare_table(
x,
methods = c("pelt", "binseg", "amoc"),
change_in = "mean",
...
)