Wraps CptNonPar::np.mojo() (McGonigle and Cho, 2023): nonparametric
moving-sum detection of changes in the marginal or joint distribution of a
(possibly multivariate) time series, robust to serial dependence.
Arguments
- x
A numeric vector or matrix (rows are time points).
- G
Moving-window bandwidth. Defaults to
max(20, 0.1 * n)observations.- lag
Time lag at which changes in the joint distribution are examined;
0targets the marginal distribution. Defaults to0.- ...
Additional arguments passed to
CptNonPar::np.mojo().