Provides a human-readable digest of a changepoint detection result, including the segment table with levels and lengths, total cost, penalty, and runtime.
Arguments
- object
A
ggcptobject.- ...
Additional arguments (ignored).
- x
A
summary.ggcptobject (forprint()).